# Features
ZenBand is a PWEM solver with a graphical user interface which is based on Tkinter library. The application has a number of functions that are usefull for 2D photonic crystal analysis:
- Photonic band diagrams
- 2D and 3D iso-frequency contours
- Omnidirectional Band Gap analysis, including band gap maps
- Field distributions

Five different unit cell types for square (cylinders, frames and rings) and hexagonal (regular hex and honeycomb) lattices are built in with the ability to import custom devices (an example on how to import devices is given in 'example' folder as well as the instuction manual). Option to choose diagonally anisotropic dielectric permittivity matrices is built in.

A description of all variables, functions and a walk through of the GUI in ZenBand is given in [ZenBand_instruction.pdf](https://github.com/user-attachments/files/21835383/ZenBand_instruction.pdf).
